@@ -32,6 +32,8 @@
 #include <libintl.h>
 #endif
 
+#include <getopt.h>
+
 #include <libxml/xmlwriter.h>
 
 #include "hivex.h"
@@ -213,7 +215,6 @@ node_start (hive_h *h, void *writer_v, hive_node_h node, const char *name)
 {
   int64_t last_modified;
   char *timebuf;
-  int ret = 0;
 
   xmlTextWriterPtr writer = (xmlTextWriterPtr) writer_v;
   XML_CHECK (xmlTextWriterStartElement, (writer, BAD_CAST "node"));
